@@ -147,7 +147,7 @@ class SerializeMCR(object):
                         elif isinstance(data[_name], dict):
                             self.__dict__[_name] = prop[_srl](data[_name])
                     elif prop[_sch]:
-                        _cls = serialize-mcr
+                        _cls = SerializeMCR
                         _cls.schema = prop[_sch]
                         if isinstance(data[_name], list):
                             self.__dict__[_name] = [_cls(o)
